@@ -24,5 +24,5 @@ urlpatterns = [
     url(r'^get_blacklisted_accounts/', views.GetBlacklistedAccounts.as_view(), name='get_blacklisted_accounts'),
     url(r'^get_aml_data/', views.getAMLTableData.as_view(), name='get_aml_data'),
     url(r'^blacklist_phone/', views.blacklistPhoneNumber.as_view(), name='blacklist_phone'),
-    url(r'^get_data_dwh/', views.GetRegisAndActHiFromDWHRequestSerializer.as_view(), name='get-data-dwh'), #nguyenhuuvinh4
+    url(r'^get_data_dwh/', views.GetRegisAndActHiFromDWHRequestSerializer.as_view(), name='get_data_dwh'),
 ]
\ No newline at end of file
