@@ -869,6 +869,7 @@ class GetDataCustConAdd(APIView):
         return base_app_utils.response(rq_srl.errors, status.HTTP_400_BAD_REQUEST, error="error")
 
 class GetRegisAndActHiFromDWHRequestSerializer(APIView):
+    print("tests GetRegisAndActHiFromDWHRequestSerializer")
     def post(self, request):
         rq_srl = fec_dbsync_serializers.GetDataCustConAddRequestSerializer(
             data=request.data)
@@ -997,6 +998,7 @@ class FraudCheckRule(APIView):
 
 
 class GetBlacklistedAccounts(APIView):
+    print("tests GetBlacklistedAccounts")
     def post(self, request):
         serialized_request = fec_dbsync_serializers.GetBlacklistedAccountsRequestSerializer(
             data=request.data)
